@@ -1,3 +1,4 @@
+//go:build !windows
 // +build !windows
 
 package host
@@ -8,17 +9,26 @@ import (
 )
 
 type consoleLogger struct {
-	info, warn, err *stdlog.Logger
+	debug, info, warn, err *stdlog.Logger
 }
 
 func NewConsoleLogger(name string) Logger {
 	return consoleLogger{
-		info: stdlog.New(os.Stderr, "INFO: ", stdlog.Ltime),
-		warn: stdlog.New(os.Stderr, "WARN: ", stdlog.Ltime),
-		err:  stdlog.New(os.Stderr, "ERROR: ", stdlog.Ltime),
+		debug: stdlog.New(os.Stderr, "DEBUG: ", stdlog.Ltime),
+		info:  stdlog.New(os.Stderr, "INFO:  ", stdlog.Ltime),
+		warn:  stdlog.New(os.Stderr, "WARN:  ", stdlog.Ltime),
+		err:   stdlog.New(os.Stderr, "ERROR: ", stdlog.Ltime),
 	}
 }
 
+func (l consoleLogger) Debug(v ...interface{}) {
+	l.debug.Print(v...)
+}
+
+func (l consoleLogger) Debugf(format string, a ...interface{}) {
+	l.debug.Printf(format, a...)
+}
+
 func (l consoleLogger) Info(v ...interface{}) {
 	l.info.Print(v...)
 }
