@@ -117,7 +117,8 @@ configure() {
         # shellcheck disable=SC2046
         add_arg "$arg" $(ask_bool "$msg" "$default")
     }
-    add_arg config "$(get_config_id)"
+    # Use config arg instead of profile to stay backward compatible
+    add_arg config "$(get_profile_id)"
 
     doc "Sending your devices name lets you filter analytics and logs by device."
     add_arg_bool_ask report-client-info 'Report device name?' true
@@ -151,7 +152,7 @@ configure() {
 
         doc "Instant refresh will force low TTL on responses sent to clients so they rely"
         doc "on CLI DNS cache. This will allow changes on your NextDNS config to be applied"
-        doc "on you LAN hosts without having to wait for their cache to expire."
+        doc "on your LAN hosts without having to wait for their cache to expire."
         if [ "$(get_config max-ttl)" = "5s" ]; then
             instant_refresh_default=true
         fi
@@ -279,12 +280,13 @@ install_deb() {
 
     # Fallback on curl, some debian based distrib don't have wget while debian
     # doesn't have curl by default.
-    ( asroot wget -qO /usr/share/keyrings/nextdns.gpg https://repo.nextdns.io/nextdns.gpg ||
-      asroot curl -sfL https://repo.nextdns.io/nextdns.gpg -o /usr/share/keyrings/nextdns.gpg ) &&
-        asroot chmod 0644 /usr/share/keyrings/nextdns.gpg &&
-        asroot sh -c 'echo "deb [signed-by=/usr/share/keyrings/nextdns.gpg] https://repo.nextdns.io/deb stable main" > /etc/apt/sources.list.d/nextdns.list' &&
+    asroot mkdir -p /etc/apt/keyrings
+    ( asroot wget -qO /etc/apt/keyrings/nextdns.gpg https://repo.nextdns.io/nextdns.gpg ||
+      asroot curl -sfL https://repo.nextdns.io/nextdns.gpg -o /etc/apt/keyrings/nextdns.gpg ) &&
+        asroot chmod 0644 /etc/apt/keyrings/nextdns.gpg &&
+        asroot sh -c 'echo "deb [signed-by=/etc/apt/keyrings/nextdns.gpg] https://repo.nextdns.io/deb stable main" > /etc/apt/sources.list.d/nextdns.list' &&
         (dpkg --compare-versions $(dpkg-query --showformat='${Version}' --show apt) ge 1.1 ||
-         asroot ln -s /usr/share/keyrings/nextdns.gpg /etc/apt/trusted.gpg.d/.) &&
+         asroot ln -s /etc/apt/keyrings/nextdns.gpg /etc/apt/trusted.gpg.d/.) &&
         (test "$OS" = "debian" && asroot apt-get -y install apt-transport-https || true) &&
         asroot apt-get update &&
         asroot apt-get install -y nextdns
@@ -464,11 +466,12 @@ uninstall_opnsense() {
 }
 
 ubios_install_source() {
-    echo "deb [signed-by=/usr/share/keyrings/nextdns.gpg] https://repo.nextdns.io/deb stable main" > /data/nextdns.list
+    echo "deb [signed-by=/etc/apt/keyrings/nextdns.gpg] https://repo.nextdns.io/deb stable main" > /data/nextdns.list
     podman exec unifi-os mv /data/nextdns.list /etc/apt/sources.list.d/nextdns.list
     rm -f /tmp/nextdns.list
     podman exec unifi-os apt-get install -y gnupg1 curl
-    podman exec unifi-os curl -sfL https://repo.nextdns.io/nextdns.gpg -o /usr/share/keyrings/nextdns.gpg
+    podman exec unifi-os mkdir -p /etc/apt/keyrings/
+    podman exec unifi-os curl -sfL https://repo.nextdns.io/nextdns.gpg -o /etc/apt/keyrings/nextdns.gpg
     podman exec unifi-os apt-get update -o Dir::Etc::sourcelist="sources.list.d/nextdns.list" -o Dir::Etc::sourceparts="-" -o APT::Get::List-Cleanup="0"
 }
 
@@ -612,32 +615,40 @@ get_config_bool() {
     echo "$2"
 }
 
-get_config_id() {
-    log_debug "Get configuration ID"
-    while [ -z "$CONFIG_ID" ]; do
+get_profile_id() {
+    log_debug "Get profile ID"
+    if [ "$CONFIG_ID" ]; then
+        # backward compat
+        PROFILE_ID="$CONFIG_ID"
+    fi
+    while [ -z "$PROFILE_ID" ]; do
         default=
-        prev_id=$(get_config config)
+        prev_id=$(get_config profile)
+        if [ -z "$prev_id" ]; then
+            # backward compat
+            prev_id=$(get_config config)
+        fi
         if [ "$prev_id" ]; then
-            log_debug "Previous config ID: $prev_id"
+            log_debug "Previous profile ID: $prev_id"
             default=" (default=$prev_id)"
         fi
-        print "NextDNS Configuration ID%s: " "$default"
+        print "NextDNS Profile ID%s: " "$default"
         read -r id
         if [ -z "$id" ]; then
             id=$prev_id
         fi
         if echo "$id" | grep -qE '^[0-9a-f]{6}$'; then
-            CONFIG_ID=$id
+            PROFILE_ID=$id
             break
         else
-            log_error "Invalid configuration ID."
+            log_error "Invalid profile ID."
             println
             println "ID format is 6 alphanumerical lowercase characters (example: 123abc)."
             println "Your ID can be found on the Setup tab of https://my.nextdns.io."
             println
         fi
     done
-    echo "$CONFIG_ID"
+    echo "$PROFILE_ID"
 }
 
 log_debug() {
