@@ -9,6 +9,7 @@ import (
 	"time"
 
 	"github.com/nextdns/nextdns/hosts"
+	"github.com/nextdns/nextdns/internal/dnsmessage"
 	"github.com/nextdns/nextdns/resolver"
 	"github.com/nextdns/nextdns/resolver/query"
 )
@@ -146,7 +147,7 @@ func (p Proxy) ListenAndServe(ctx context.Context) error {
 	<-ctx.Done()
 	errs <- ctx.Err()
 	for _, close := range closeAll {
-		close()
+		_ = close()
 	}
 	// Wait for the two sockets (+ ctx err) to be terminated and return the
 	// initial error.
@@ -169,7 +170,9 @@ func (p Proxy) Resolve(ctx context.Context, q query.Query, buf []byte) (n int, i
 		}
 	}
 
-	if !p.BogusPriv || q.Type != query.TypePTR || !isPrivateReverse(q.Name) {
+	priv := q.Type == query.TypePTR && isPrivateReverse(q.Name)
+
+	if !p.BogusPriv || !priv {
 		n, i, err = p.Upstream.Resolve(ctx, q, buf)
 	}
 
@@ -179,6 +182,11 @@ func (p Proxy) Resolve(ctx context.Context, q query.Query, buf []byte) (n int, i
 		}
 	}
 
+	if p.BogusPriv && priv {
+		n = replyRCode(dnsmessage.RCodeNameError, q, buf)
+		return n, i, nil
+	}
+
 	return n, i, err
 }
 
