@@ -219,7 +219,7 @@ func run(args []string) error {
 				"User-Agent": []string{fmt.Sprintf("nextdns-cli/%s (%s; %s; %s)", version, platform, runtime.GOARCH, host.InitType())},
 			},
 		},
-		Manager: nextdnsEndpointManager(log, func() bool {
+		Manager: nextdnsEndpointManager(log, c.Debug, func() bool {
 			// Backward compat: the captive portal is now somewhat always enabled,
 			// but for those who enabled it in the past, disable the delay after which
 			// the fallback is disabled.
@@ -262,12 +262,12 @@ func run(args []string) error {
 	p.resolver.DNS53.MaxTTL = maxTTL
 	p.resolver.DOH.MaxTTL = maxTTL
 
-	if len(c.Conf) == 0 || (len(c.Conf) == 1 && c.Conf.Get(nil, nil) != "") {
+	if len(c.Profile) == 0 || (len(c.Profile) == 1 && c.Profile.Get(nil, nil) != "") {
 		// Optimize for no dynamic configuration.
-		p.resolver.DOH.URL = "https://dns.nextdns.io/" + c.Conf.Get(nil, nil)
+		p.resolver.DOH.URL = "https://dns.nextdns.io/" + c.Profile.Get(nil, nil)
 	} else {
 		p.resolver.DOH.GetURL = func(q query.Query) string {
-			return "https://dns.nextdns.io/" + c.Conf.Get(q.PeerIP, q.MAC)
+			return "https://dns.nextdns.io/" + c.Profile.Get(q.PeerIP, q.MAC)
 		}
 	}
 
@@ -323,7 +323,7 @@ func run(args []string) error {
 				return d
 			})
 		}
-		setupClientReporting(p, &c.Conf, r)
+		setupClientReporting(p, &c.Profile, r)
 	}
 	if p.Proxy.DiscoveryResolver == nil && c.DiscoveryDNS != "" {
 		p.Proxy.DiscoveryResolver = &discovery.DNS{Upstream: c.DiscoveryDNS}
@@ -423,7 +423,7 @@ func isLocalhostMode(c *config.Config) bool {
 
 // nextdnsEndpointManager returns a endpoint.Manager configured to connect to
 // NextDNS using different steering techniques.
-func nextdnsEndpointManager(log host.Logger, canFallback func() bool) *endpoint.Manager {
+func nextdnsEndpointManager(log host.Logger, debug bool, canFallback func() bool) *endpoint.Manager {
 	m := &endpoint.Manager{
 		Providers: []endpoint.Provider{
 			// Prefer unicast routing.
@@ -502,10 +502,15 @@ func nextdnsEndpointManager(log host.Logger, canFallback func() bool) *endpoint.
 		}
 		return 0 // use default MinTestInterval
 	}
+	if debug {
+		m.DebugLog = func(msg string) {
+			log.Debug(msg)
+		}
+	}
 	return m
 }
 
-func setupClientReporting(p *proxySvc, conf *config.Configs, r discovery.Resolver) {
+func setupClientReporting(p *proxySvc, conf *config.Profiles, r discovery.Resolver) {
 	deviceName, _ := host.Name()
 	deviceID, _ := machineid.ProtectedID("NextDNS")
 	if len(deviceID) > 5 {
